@@ -695,6 +695,9 @@ gnome_canvas_rich_text_ext_unrealize(GnomeCanvasItem *item)
 {
 	GnomeCanvasRichTextExt *text = GNOME_CANVAS_RICH_TEXT_EXT(item);
 
+	/*remove idle calls to request_update */
+	while (	g_idle_remove_by_data (item));
+
 	gnome_canvas_rich_text_ext_destroy_layout(text);
 
 	(* GNOME_CANVAS_ITEM_CLASS(parent_class)->unrealize)(item);
