@@ -50,7 +50,12 @@
 using namespace OpenBabel;
 using namespace std;
 
+
+#ifdef GCU_OLD_VER
 gcpDocument::gcpDocument(): Object(DocumentType)
+#else
+gcpDocument::gcpDocument(): Document ()
+#endif
 {
 	m_pView = NULL;
 	m_filename = NULL;
@@ -232,6 +237,7 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 			AddBond(pBond);
 		}
 	}
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	return true;
 }
 
@@ -473,39 +479,61 @@ bool gcpDocument::Load(xmlNodePtr root)
 	char* tmp;
 	Object* pObject;
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"id");
-	if (tmp) SetId(tmp);
+	if (tmp)
+	{
+		SetId(tmp);
+		xmlFree(tmp);
+	}
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"creation");
 	if (tmp)
 	{
 		g_date_set_parse(&CreationDate, tmp);
 		if (!g_date_valid(&CreationDate)) g_date_clear(&CreationDate, 1);
+		xmlFree(tmp);
 	}
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"revision");
 	if (tmp)
 	{
 		g_date_set_parse(&RevisionDate, tmp);
 		if (!g_date_valid(&RevisionDate)) g_date_clear(&RevisionDate, 1);
+		xmlFree(tmp);
 	}
 
 	node = GetNodeByName(root, "title");
 	if (node)
 	{
 		tmp = (char*)xmlNodeGetContent(node);
-		if (tmp) m_title = g_strdup(tmp);
+		if (tmp)
+		{
+			m_title = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 	node = GetNodeByName(root, "author");
 	if (node)
 	{
 		tmp = (char*)xmlGetProp(node, (xmlChar*)"name");
-		if (tmp) m_author = g_strdup(tmp);
+		if (tmp)
+		{
+			m_author = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 		tmp = (char*)xmlGetProp(node, (xmlChar*)"e-mail");
-		if (tmp) m_mail = g_strdup(tmp);
+		if (tmp)
+		{
+			m_mail = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 	node = GetNodeByName(root, "comment");
 	if (node)
 	{
 		tmp = (char*)xmlNodeGetContent(node);
-		if (tmp) m_comment = g_strdup(tmp);
+		if (tmp)
+		{
+			m_comment = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 
 	m_bIsLoading = true;
@@ -543,6 +571,7 @@ bool gcpDocument::Load(xmlNodePtr root)
 		node = GetNextNodeByName(node->next, "text");
 	}
 	m_bIsLoading = false;
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	return true;
 }
 	
@@ -819,6 +848,7 @@ void gcpDocument::OnUndo()
 	}
 	if (m_UndoList.empty())
 		ActivateMenu(EditMenu, UndoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
 }
 
@@ -836,6 +866,7 @@ void gcpDocument::OnRedo()
 	}
 	if (m_RedoList.empty())
 		ActivateMenu(EditMenu, RedoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
 }
 
@@ -850,6 +881,7 @@ void gcpDocument::FinishOperation()
 		m_RedoList.pop_front();
 	}
 	ActivateMenu(EditMenu, RedoMenu, false);
+	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_pCurOp = NULL;
 }
 
@@ -894,6 +926,7 @@ void gcpDocument::SetActive()
 {
 	ActivateMenu(EditMenu, UndoMenu, !m_UndoList.empty());
 	ActivateMenu(EditMenu, RedoMenu, !m_RedoList.empty());
+	ActivateMenu(EditMenu, SaveAsImageMenu, HasChildren ());
 }
 
 extern xmlDocPtr pXmlDoc;
