@@ -287,7 +287,11 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 	if (!strcmp((const char*)node->name, "text"))
 	{
 		tmp = (char*) xmlNodeGetContent(node);
-		gtk_text_buffer_insert(m_buf, CurIter, tmp, -1);
+		if (tmp)
+		{
+			gtk_text_buffer_insert(m_buf, CurIter, tmp, -1);
+			xmlFree(tmp);
+		}
 		return true;
 	}
 	else if (!strcmp((const char*)node->name, "br"))
@@ -318,7 +322,9 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 			gtk_text_tag_table_add(TextTagTable, tag);
 			g_object_unref((GObject*)tag);
 		}
-		return LoadTaggedNode(node, CurIter, TagName);
+		bool result = LoadTaggedNode(node, CurIter, TagName);
+		xmlFree(TagName);
+		return result;
 	}
 	else return false;
 }
@@ -416,6 +422,13 @@ bool gcpText::OnChanged(GtkTextBuffer *textbuffer)
 	m_height = 1;
 	bool bNotEnd = true;
 	m_length = 0;
+	if (!gtk_text_buffer_get_char_count (m_buf)) {
+		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+		m_height = rect.height + 1;
+		m_length = 1;
+		pView->Update (this);
+		return true;
+	}
 	while (bNotEnd)
 	{
 		bNotEnd = gtk_text_iter_forward_to_line_end(&iter);
