@@ -30,7 +30,11 @@
 #include <gnome.h>
 #include <map>
 #include <list>
-#include <chemistry/object.h>
+#ifdef GCU_OLD_VER
+#	include <chemistry/object.h>
+#else
+#	include <gcu/object.h>
+#endif
 
 using namespace gcu;
 
